@@ -1,5 +1,7 @@
 element_sorter <- function(ElementList = "all", ElementOrder = "alphabetical") {
+  ##
   IDSL.UFA::IUPAC_Isotopes
+  ##
   NonUniElements <- IUPAC_Isotopes$element
   Valence_EL <- IUPAC_Isotopes$valence
   if (tolower(ElementList[1]) == "all") {
@@ -14,7 +16,7 @@ element_sorter <- function(ElementList = "all", ElementOrder = "alphabetical") {
     Elements <- cbind(Elements, X)
     Elements <- Elements[order(Elements[, 2], decreasing = TRUE), ]
     OutputElements <- Elements[, 1]
-  } else if(tolower(ElementOrder) == "same") {
+  } else if (tolower(ElementOrder) == "same") {
     OutputElements <- Elements
   }
   Elements_mass_abundance <- vector(mode = "list", L_Elements)
@@ -24,6 +26,10 @@ element_sorter <- function(ElementList = "all", ElementOrder = "alphabetical") {
     Elements_mass_abundance[[i]] <- list(IUPAC_Isotopes$mass[x_el], IUPAC_Isotopes$abundance[x_el])
     valence[i] <- Valence_EL[x_el[1]]
   }
+  ##
+  names(Elements_mass_abundance) <- c("Mass", "Abundance")
+  ##
   ElementList <- list(OutputElements, Elements_mass_abundance, valence)
+  names(ElementList) <- c("Elements", "massAbundanceList", "Valence")
   return(ElementList)
 }
